@@ -15,7 +15,7 @@
 
 """Common DNSSEC-related functions and constants."""
 
-import cStringIO
+from io import BytesIO
 import struct
 import time
 
@@ -27,14 +27,17 @@ import dns.rdataset
 import dns.rdata
 import dns.rdatatype
 import dns.rdataclass
+from ._compat import string_types
+
 
 class UnsupportedAlgorithm(dns.exception.DNSException):
-    """Raised if an algorithm is not supported."""
-    pass
+
+    """The DNSSEC algorithm is not supported."""
+
 
 class ValidationFailure(dns.exception.DNSException):
+
     """The DNSSEC signature is invalid."""
-    pass
 
 RSAMD5 = 1
 DH = 2
@@ -52,27 +55,28 @@ PRIVATEDNS = 253
 PRIVATEOID = 254
 
 _algorithm_by_text = {
-    'RSAMD5' : RSAMD5,
-    'DH' : DH,
-    'DSA' : DSA,
-    'ECC' : ECC,
-    'RSASHA1' : RSASHA1,
-    'DSANSEC3SHA1' : DSANSEC3SHA1,
-    'RSASHA1NSEC3SHA1' : RSASHA1NSEC3SHA1,
-    'RSASHA256' : RSASHA256,
-    'RSASHA512' : RSASHA512,
-    'INDIRECT' : INDIRECT,
-    'ECDSAP256SHA256' : ECDSAP256SHA256,
-    'ECDSAP384SHA384' : ECDSAP384SHA384,
-    'PRIVATEDNS' : PRIVATEDNS,
-    'PRIVATEOID' : PRIVATEOID,
-    }
+    'RSAMD5': RSAMD5,
+    'DH': DH,
+    'DSA': DSA,
+    'ECC': ECC,
+    'RSASHA1': RSASHA1,
+    'DSANSEC3SHA1': DSANSEC3SHA1,
+    'RSASHA1NSEC3SHA1': RSASHA1NSEC3SHA1,
+    'RSASHA256': RSASHA256,
+    'RSASHA512': RSASHA512,
+    'INDIRECT': INDIRECT,
+    'ECDSAP256SHA256': ECDSAP256SHA256,
+    'ECDSAP384SHA384': ECDSAP384SHA384,
+    'PRIVATEDNS': PRIVATEDNS,
+    'PRIVATEOID': PRIVATEOID,
+}
 
 # We construct the inverse mapping programmatically to ensure that we
 # cannot make any mistakes (e.g. omissions, cut-and-paste errors) that
 # would cause the mapping not to be true inverse.
 
-_algorithm_by_value = dict([(y, x) for x, y in _algorithm_by_text.iteritems()])
+_algorithm_by_value = dict((y, x) for x, y in _algorithm_by_text.items())
+
 
 def algorithm_from_text(text):
     """Convert text into a DNSSEC algorithm value
@@ -83,6 +87,7 @@ def algorithm_from_text(text):
         value = int(text)
     return value
 
+
 def algorithm_to_text(value):
     """Convert a DNSSEC algorithm value to text
     @rtype: string"""
@@ -92,35 +97,40 @@ def algorithm_to_text(value):
         text = str(value)
     return text
 
+
 def _to_rdata(record, origin):
-    s = cStringIO.StringIO()
+    s = BytesIO()
     record.to_wire(s, origin=origin)
     return s.getvalue()
 
+
 def key_id(key, origin=None):
     rdata = _to_rdata(key, origin)
+    rdata = bytearray(rdata)
     if key.algorithm == RSAMD5:
-        return (ord(rdata[-3]) << 8) + ord(rdata[-2])
+        return (rdata[-3] << 8) + rdata[-2]
     else:
         total = 0
         for i in range(len(rdata) // 2):
-            total += (ord(rdata[2 * i]) << 8) + ord(rdata[2 * i + 1])
+            total += (rdata[2 * i] << 8) + \
+                rdata[2 * i + 1]
         if len(rdata) % 2 != 0:
-            total += ord(rdata[len(rdata) - 1]) << 8
-        total += ((total >> 16) & 0xffff);
+            total += rdata[len(rdata) - 1] << 8
+        total += ((total >> 16) & 0xffff)
         return total & 0xffff
 
+
 def make_ds(name, key, algorithm, origin=None):
     if algorithm.upper() == 'SHA1':
         dsalg = 1
-        hash = dns.hash.get('SHA1')()
+        hash = dns.hash.hashes['SHA1']()
     elif algorithm.upper() == 'SHA256':
         dsalg = 2
-        hash = dns.hash.get('SHA256')()
+        hash = dns.hash.hashes['SHA256']()
     else:
-        raise UnsupportedAlgorithm, 'unsupported algorithm "%s"' % algorithm
+        raise UnsupportedAlgorithm('unsupported algorithm "%s"' % algorithm)
 
-    if isinstance(name, (str, unicode)):
+    if isinstance(name, string_types):
         name = dns.name.from_text(name, origin)
     hash.update(name.canonicalize().to_wire())
     hash.update(_to_rdata(key, origin))
@@ -130,8 +140,9 @@ def make_ds(name, key, algorithm, origin=None):
     return dns.rdata.from_wire(dns.rdataclass.IN, dns.rdatatype.DS, dsrdata, 0,
                                len(dsrdata))
 
+
 def _find_candidate_keys(keys, rrsig):
-    candidate_keys=[]
+    candidate_keys = []
     value = keys.get(rrsig.signer)
     if value is None:
         return None
@@ -145,49 +156,59 @@ def _find_candidate_keys(keys, rrsig):
         rdataset = value
     for rdata in rdataset:
         if rdata.algorithm == rrsig.algorithm and \
-               key_id(rdata) == rrsig.key_tag:
+                key_id(rdata) == rrsig.key_tag:
             candidate_keys.append(rdata)
     return candidate_keys
 
+
 def _is_rsa(algorithm):
     return algorithm in (RSAMD5, RSASHA1,
                          RSASHA1NSEC3SHA1, RSASHA256,
                          RSASHA512)
 
+
 def _is_dsa(algorithm):
     return algorithm in (DSA, DSANSEC3SHA1)
 
+
 def _is_ecdsa(algorithm):
     return _have_ecdsa and (algorithm in (ECDSAP256SHA256, ECDSAP384SHA384))
 
+
 def _is_md5(algorithm):
     return algorithm == RSAMD5
 
+
 def _is_sha1(algorithm):
     return algorithm in (DSA, RSASHA1,
                          DSANSEC3SHA1, RSASHA1NSEC3SHA1)
 
+
 def _is_sha256(algorithm):
     return algorithm in (RSASHA256, ECDSAP256SHA256)
 
+
 def _is_sha384(algorithm):
     return algorithm == ECDSAP384SHA384
 
+
 def _is_sha512(algorithm):
     return algorithm == RSASHA512
 
+
 def _make_hash(algorithm):
     if _is_md5(algorithm):
-        return dns.hash.get('MD5')()
+        return dns.hash.hashes['MD5']()
     if _is_sha1(algorithm):
-        return dns.hash.get('SHA1')()
+        return dns.hash.hashes['SHA1']()
     if _is_sha256(algorithm):
-        return dns.hash.get('SHA256')()
+        return dns.hash.hashes['SHA256']()
     if _is_sha384(algorithm):
-        return dns.hash.get('SHA384')()
+        return dns.hash.hashes['SHA384']()
     if _is_sha512(algorithm):
-        return dns.hash.get('SHA512')()
-    raise ValidationFailure, 'unknown hash for algorithm %u' % algorithm
+        return dns.hash.hashes['SHA512']()
+    raise ValidationFailure('unknown hash for algorithm %u' % algorithm)
+
 
 def _make_algorithm_id(algorithm):
     if _is_md5(algorithm):
@@ -199,13 +220,14 @@ def _make_algorithm_id(algorithm):
     elif _is_sha512(algorithm):
         oid = [0x60, 0x86, 0x48, 0x01, 0x65, 0x03, 0x04, 0x02, 0x03]
     else:
-        raise ValidationFailure, 'unknown algorithm %u' % algorithm
+        raise ValidationFailure('unknown algorithm %u' % algorithm)
     olen = len(oid)
     dlen = _make_hash(algorithm).digest_size
     idbytes = [0x30] + [8 + olen + dlen] + \
               [0x30, olen + 4] + [0x06, olen] + oid + \
               [0x05, 0x00] + [0x04, dlen]
-    return ''.join(map(chr, idbytes))
+    return struct.pack('!%dB' % len(idbytes), *idbytes)
+
 
 def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
     """Validate an RRset against a single signature rdata
@@ -219,7 +241,8 @@ def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
     @param rrsig: The signature rdata
     @type rrsig: dns.rrset.Rdata
     @param keys: The key dictionary.
-    @type keys: a dictionary keyed by dns.name.Name with node or rdataset values
+    @type keys: a dictionary keyed by dns.name.Name with node or rdataset
+    values
     @param origin: The origin to use for relative names
     @type origin: dns.name.Name or None
     @param now: The time to use when validating the signatures.  The default
@@ -227,15 +250,15 @@ def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
     @type now: int
     """
 
-    if isinstance(origin, (str, unicode)):
+    if isinstance(origin, string_types):
         origin = dns.name.from_text(origin, dns.name.root)
 
     for candidate_key in _find_candidate_keys(keys, rrsig):
         if not candidate_key:
-            raise ValidationFailure, 'unknown key'
+            raise ValidationFailure('unknown key')
 
-        # For convenience, allow the rrset to be specified as a (name, rdataset)
-        # tuple as well as a proper rrset
+        # For convenience, allow the rrset to be specified as a (name,
+        # rdataset) tuple as well as a proper rrset
         if isinstance(rrset, tuple):
             rrname = rrset[0]
             rdataset = rrset[1]
@@ -246,21 +269,21 @@ def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
         if now is None:
             now = time.time()
         if rrsig.expiration < now:
-            raise ValidationFailure, 'expired'
+            raise ValidationFailure('expired')
         if rrsig.inception > now:
-            raise ValidationFailure, 'not yet valid'
+            raise ValidationFailure('not yet valid')
 
         hash = _make_hash(rrsig.algorithm)
 
         if _is_rsa(rrsig.algorithm):
             keyptr = candidate_key.key
-            (bytes,) = struct.unpack('!B', keyptr[0:1])
+            (bytes_,) = struct.unpack('!B', keyptr[0:1])
             keyptr = keyptr[1:]
-            if bytes == 0:
-                (bytes,) = struct.unpack('!H', keyptr[0:2])
+            if bytes_ == 0:
+                (bytes_,) = struct.unpack('!H', keyptr[0:2])
                 keyptr = keyptr[2:]
-            rsa_e = keyptr[0:bytes]
-            rsa_n = keyptr[bytes:]
+            rsa_e = keyptr[0:bytes_]
+            rsa_n = keyptr[bytes_:]
             keylen = len(rsa_n) * 8
             pubkey = Crypto.PublicKey.RSA.construct(
                 (Crypto.Util.number.bytes_to_long(rsa_n),
@@ -290,14 +313,12 @@ def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
             if rrsig.algorithm == ECDSAP256SHA256:
                 curve = ecdsa.curves.NIST256p
                 key_len = 32
-                digest_len = 32
             elif rrsig.algorithm == ECDSAP384SHA384:
                 curve = ecdsa.curves.NIST384p
                 key_len = 48
-                digest_len = 48
             else:
                 # shouldn't happen
-                raise ValidationFailure, 'unknown ECDSA curve'
+                raise ValidationFailure('unknown ECDSA curve')
             keyptr = candidate_key.key
             x = Crypto.Util.number.bytes_to_long(keyptr[0:key_len])
             y = Crypto.Util.number.bytes_to_long(keyptr[key_len:key_len * 2])
@@ -311,7 +332,7 @@ def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
             sig = ecdsa.ecdsa.Signature(Crypto.Util.number.bytes_to_long(r),
                                         Crypto.Util.number.bytes_to_long(s))
         else:
-            raise ValidationFailure, 'unknown algorithm %u' % rrsig.algorithm
+            raise ValidationFailure('unknown algorithm %u' % rrsig.algorithm)
 
         hash.update(_to_rdata(rrsig, origin)[:18])
         hash.update(rrsig.signer.to_digestable(origin))
@@ -322,7 +343,7 @@ def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
         rrnamebuf = rrname.to_digestable(origin)
         rrfixed = struct.pack('!HHI', rdataset.rdtype, rdataset.rdclass,
                               rrsig.original_ttl)
-        rrlist = sorted(rdataset);
+        rrlist = sorted(rdataset)
         for rr in rrlist:
             hash.update(rrnamebuf)
             hash.update(rrfixed)
@@ -337,18 +358,20 @@ def _validate_rrsig(rrset, rrsig, keys, origin=None, now=None):
             # PKCS1 algorithm identifier goop
             digest = _make_algorithm_id(rrsig.algorithm) + digest
             padlen = keylen // 8 - len(digest) - 3
-            digest = chr(0) + chr(1) + chr(0xFF) * padlen + chr(0) + digest
+            digest = struct.pack('!%dB' % (2 + padlen + 1),
+                                 *([0, 1] + [0xFF] * padlen + [0])) + digest
         elif _is_dsa(rrsig.algorithm) or _is_ecdsa(rrsig.algorithm):
             pass
         else:
             # Raise here for code clarity; this won't actually ever happen
             # since if the algorithm is really unknown we'd already have
             # raised an exception above
-            raise ValidationFailure, 'unknown algorithm %u' % rrsig.algorithm
+            raise ValidationFailure('unknown algorithm %u' % rrsig.algorithm)
 
         if pubkey.verify(digest, sig):
             return
-    raise ValidationFailure, 'verify failure'
+    raise ValidationFailure('verify failure')
+
 
 def _validate(rrset, rrsigset, keys, origin=None, now=None):
     """Validate an RRset
@@ -360,7 +383,8 @@ def _validate(rrset, rrsigset, keys, origin=None, now=None):
     @type rrsigset: dns.rrset.RRset or (dns.name.Name, dns.rdataset.Rdataset)
     tuple
     @param keys: The key dictionary.
-    @type keys: a dictionary keyed by dns.name.Name with node or rdataset values
+    @type keys: a dictionary keyed by dns.name.Name with node or rdataset
+    values
     @param origin: The origin to use for relative names
     @type origin: dns.name.Name or None
     @param now: The time to use when validating the signatures.  The default
@@ -368,7 +392,7 @@ def _validate(rrset, rrsigset, keys, origin=None, now=None):
     @type now: int
     """
 
-    if isinstance(origin, (str, unicode)):
+    if isinstance(origin, string_types):
         origin = dns.name.from_text(origin, dns.name.root)
 
     if isinstance(rrset, tuple):
@@ -386,18 +410,19 @@ def _validate(rrset, rrsigset, keys, origin=None, now=None):
     rrname = rrname.choose_relativity(origin)
     rrsigname = rrname.choose_relativity(origin)
     if rrname != rrsigname:
-        raise ValidationFailure, "owner names do not match"
+        raise ValidationFailure("owner names do not match")
 
     for rrsig in rrsigrdataset:
         try:
             _validate_rrsig(rrset, rrsig, keys, origin, now)
             return
-        except ValidationFailure, e:
+        except ValidationFailure:
             pass
-    raise ValidationFailure, "no RRSIGs validated"
+    raise ValidationFailure("no RRSIGs validated")
+
 
 def _need_pycrypto(*args, **kwargs):
-    raise NotImplementedError, "DNSSEC validation requires pycrypto"
+    raise NotImplementedError("DNSSEC validation requires pycrypto")
 
 try:
     import Crypto.PublicKey.RSA
@@ -419,9 +444,11 @@ try:
     _have_ecdsa = True
 
     class ECKeyWrapper(object):
+
         def __init__(self, key, key_len):
             self.key = key
             self.key_len = key_len
+
         def verify(self, digest, sig):
             diglong = Crypto.Util.number.bytes_to_long(digest)
             return self.key.pubkey.verifies(diglong, sig)
