@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2007, 2009 Nominum, Inc.
+# Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -34,6 +34,7 @@ try:
 except AttributeError:
     AF_INET6 = 9999
 
+
 def inet_pton(family, text):
     """Convert the textual form of a network address into its binary form.
 
@@ -45,7 +46,7 @@ def inet_pton(family, text):
     implemented.
     @rtype: string
     """
-    
+
     if family == AF_INET:
         return dns.ipv4.inet_aton(text)
     elif family == AF_INET6:
@@ -53,6 +54,7 @@ def inet_pton(family, text):
     else:
         raise NotImplementedError
 
+
 def inet_ntop(family, address):
     """Convert the binary form of a network address into its textual form.
 
@@ -71,6 +73,7 @@ def inet_ntop(family, address):
     else:
         raise NotImplementedError
 
+
 def af_for_address(text):
     """Determine the address family of a textual-form network address.
 
@@ -80,15 +83,16 @@ def af_for_address(text):
     @rtype: int
     """
     try:
-        junk = dns.ipv4.inet_aton(text)
+        dns.ipv4.inet_aton(text)
         return AF_INET
-    except:
+    except Exception:
         try:
-            junk = dns.ipv6.inet_aton(text)
+            dns.ipv6.inet_aton(text)
             return AF_INET6
         except:
             raise ValueError
 
+
 def is_multicast(text):
     """Is the textual-form network address a multicast address?
 
@@ -98,11 +102,10 @@ def is_multicast(text):
     """
     try:
         first = ord(dns.ipv4.inet_aton(text)[0])
-        return (first >= 224 and first <= 239)
-    except:
+        return first >= 224 and first <= 239
+    except Exception:
         try:
             first = ord(dns.ipv6.inet_aton(text)[0])
-            return (first == 255)
-        except:
+            return first == 255
+        except Exception:
             raise ValueError
-    
