@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004 Nominum, Inc.
+# Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -15,7 +15,9 @@
 
 """A simple Set class."""
 
+
 class Set(object):
+
     """A simple set class.
 
     Sets are not in Python until 2.3, and rdata are not immutable so
@@ -26,25 +28,25 @@ class Set(object):
     @type items: list"""
 
     __slots__ = ['items']
-    
+
     def __init__(self, items=None):
         """Initialize the set.
 
         @param items: the initial set of items
         @type items: any iterable or None
         """
-        
+
         self.items = []
-        if not items is None:
+        if items is not None:
             for item in items:
                 self.add(item)
 
     def __repr__(self):
         return "dns.simpleset.Set(%s)" % repr(self.items)
-        
+
     def add(self, item):
         """Add an item to the set."""
-        if not item in self.items:
+        if item not in self.items:
             self.items.append(item)
 
     def remove(self, item):
@@ -70,7 +72,7 @@ class Set(object):
         return new instances (e.g. union) once, and keep using them in
         subclasses.
         """
-        
+
         cls = self.__class__
         obj = cls.__new__(cls)
         obj.items = list(self.items)
@@ -79,7 +81,7 @@ class Set(object):
     def __copy__(self):
         """Make a (shallow) copy of the set."""
         return self._clone()
-        
+
     def copy(self):
         """Make a (shallow) copy of the set."""
         return self._clone()
@@ -91,7 +93,7 @@ class Set(object):
         @type other: Set object
         """
         if not isinstance(other, Set):
-            raise ValueError, 'other must be a Set instance'
+            raise ValueError('other must be a Set instance')
         if self is other:
             return
         for item in other.items:
@@ -104,7 +106,7 @@ class Set(object):
         @type other: Set object
         """
         if not isinstance(other, Set):
-            raise ValueError, 'other must be a Set instance'
+            raise ValueError('other must be a Set instance')
         if self is other:
             return
         # we make a copy of the list so that we can remove items from
@@ -120,7 +122,7 @@ class Set(object):
         @type other: Set object
         """
         if not isinstance(other, Set):
-            raise ValueError, 'other must be a Set instance'
+            raise ValueError('other must be a Set instance')
         if self is other:
             self.items = []
         else:
@@ -134,7 +136,7 @@ class Set(object):
         @type other: Set object
         @rtype: the same type as I{self}
         """
-        
+
         obj = self._clone()
         obj.union_update(other)
         return obj
@@ -208,10 +210,10 @@ class Set(object):
         # Yes, this is inefficient but the sets we're dealing with are
         # usually quite small, so it shouldn't hurt too much.
         for item in self.items:
-            if not item in other.items:
+            if item not in other.items:
                 return False
         for item in other.items:
-            if not item in self.items:
+            if item not in self.items:
                 return False
         return True
 
@@ -230,22 +232,16 @@ class Set(object):
     def __delitem__(self, i):
         del self.items[i]
 
-    def __getslice__(self, i, j):
-        return self.items[i:j]
-
-    def __delslice__(self, i, j):
-        del self.items[i:j]
-
     def issubset(self, other):
         """Is I{self} a subset of I{other}?
 
         @rtype: bool
         """
-        
+
         if not isinstance(other, Set):
-            raise ValueError, 'other must be a Set instance'
+            raise ValueError('other must be a Set instance')
         for item in self.items:
-            if not item in other.items:
+            if item not in other.items:
                 return False
         return True
 
@@ -256,8 +252,8 @@ class Set(object):
         """
 
         if not isinstance(other, Set):
-            raise ValueError, 'other must be a Set instance'
+            raise ValueError('other must be a Set instance')
         for item in other.items:
-            if not item in self.items:
+            if item not in self.items:
                 return False
         return True
