@@ -132,6 +132,59 @@ class ZoneTestCase(unittest.TestCase):
                 os.unlink(here('example2.out'))
         self.failUnless(ok)
 
+    def testToFileTextualStream(self):
+        z = dns.zone.from_text(example_text, 'example.', relativize=True)
+        f = StringIO()
+        z.to_file(f)
+        out = f.getvalue()
+        f.close()
+        self.assertEqual(out, example_text_output)
+
+    def testToFileBinaryStream(self):
+        z = dns.zone.from_text(example_text, 'example.', relativize=True)
+        f = BytesIO()
+        z.to_file(f)
+        out = f.getvalue()
+        f.close()
+        self.assertEqual(out, example_text_output.encode())
+
+    def testToFileTextual(self):
+        z = dns.zone.from_file(here('example'), 'example')
+        try:
+            f = open(here('example3-textual.out'), 'w')
+            z.to_file(f)
+            f.close()
+            ok = filecmp.cmp(here('example3-textual.out'),
+                             here('example3.good'))
+        finally:
+            if not _keep_output:
+                os.unlink(here('example3-textual.out'))
+        self.failUnless(ok)
+
+    def testToFileBinary(self):
+        z = dns.zone.from_file(here('example'), 'example')
+        try:
+            f = open(here('example3-binary.out'), 'wb')
+            z.to_file(f)
+            f.close()
+            ok = filecmp.cmp(here('example3-binary.out'),
+                             here('example3.good'))
+        finally:
+            if not _keep_output:
+                os.unlink(here('example3-binary.out'))
+        self.failUnless(ok)
+
+    def testToFileFilename(self):
+        z = dns.zone.from_file(here('example'), 'example')
+        try:
+            z.to_file('example3-filename.out')
+            ok = filecmp.cmp(here('example3-filename.out'),
+                             here('example3.good'))
+        finally:
+            if not _keep_output:
+                os.unlink(here('example3-filename.out'))
+        self.failUnless(ok)
+
     def testToText(self):
         z = dns.zone.from_file(here('example'), 'example')
         ok = False
@@ -166,7 +219,7 @@ class ZoneTestCase(unittest.TestCase):
         f = BytesIO()
         o = dns.name.from_text('example.')
         z = dns.zone.from_file(here('example'), o)
-        for (name, node) in z.items():
+        for node in z.values():
             for rds in node:
                 for rd in rds:
                     f.seek(0)
@@ -175,7 +228,7 @@ class ZoneTestCase(unittest.TestCase):
                     wire = f.getvalue()
                     rd2 = dns.rdata.from_wire(rds.rdclass, rds.rdtype,
                                               wire, 0, len(wire),
-                                              origin = o)
+                                              origin=o)
                     self.failUnless(rd == rd2)
 
     def testEqual(self):
@@ -211,7 +264,7 @@ class ZoneTestCase(unittest.TestCase):
     def testFindRdataset2(self):
         def bad():
             z = dns.zone.from_text(example_text, 'example.', relativize=True)
-            rds = z.find_rdataset('@', 'loc')
+            z.find_rdataset('@', 'loc')
         self.failUnlessRaises(KeyError, bad)
 
     def testFindRRset1(self):
@@ -223,7 +276,7 @@ class ZoneTestCase(unittest.TestCase):
     def testFindRRset2(self):
         def bad():
             z = dns.zone.from_text(example_text, 'example.', relativize=True)
-            rrs = z.find_rrset('@', 'loc')
+            z.find_rrset('@', 'loc')
         self.failUnlessRaises(KeyError, bad)
 
     def testGetRdataset1(self):
@@ -235,7 +288,7 @@ class ZoneTestCase(unittest.TestCase):
     def testGetRdataset2(self):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
         rds = z.get_rdataset('@', 'loc')
-        self.failUnless(rds == None)
+        self.failUnless(rds is None)
 
     def testGetRRset1(self):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
@@ -246,7 +299,7 @@ class ZoneTestCase(unittest.TestCase):
     def testGetRRset2(self):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
         rrs = z.get_rrset('@', 'loc')
-        self.failUnless(rrs == None)
+        self.failUnless(rrs is None)
 
     def testReplaceRdataset1(self):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
@@ -285,7 +338,7 @@ class ZoneTestCase(unittest.TestCase):
         def bad():
             z = dns.zone.from_text(example_text, 'example.', relativize=True)
             node = z['@']
-            rds = node.find_rdataset(dns.rdataclass.IN, dns.rdatatype.LOC)
+            node.find_rdataset(dns.rdataclass.IN, dns.rdatatype.LOC)
         self.failUnlessRaises(KeyError, bad)
 
     def testNodeGetRdataset1(self):
@@ -299,21 +352,21 @@ class ZoneTestCase(unittest.TestCase):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
         node = z['@']
         rds = node.get_rdataset(dns.rdataclass.IN, dns.rdatatype.LOC)
-        self.failUnless(rds == None)
+        self.failUnless(rds is None)
 
     def testNodeDeleteRdataset1(self):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
         node = z['@']
-        rds = node.delete_rdataset(dns.rdataclass.IN, dns.rdatatype.SOA)
+        node.delete_rdataset(dns.rdataclass.IN, dns.rdatatype.SOA)
         rds = node.get_rdataset(dns.rdataclass.IN, dns.rdatatype.SOA)
-        self.failUnless(rds == None)
+        self.failUnless(rds is None)
 
     def testNodeDeleteRdataset2(self):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
         node = z['@']
-        rds = node.delete_rdataset(dns.rdataclass.IN, dns.rdatatype.LOC)
+        node.delete_rdataset(dns.rdataclass.IN, dns.rdatatype.LOC)
         rds = node.get_rdataset(dns.rdataclass.IN, dns.rdatatype.LOC)
-        self.failUnless(rds == None)
+        self.failUnless(rds is None)
 
     def testIterateRdatasets(self):
         z = dns.zone.from_text(example_text, 'example.', relativize=True)
@@ -391,14 +444,12 @@ class ZoneTestCase(unittest.TestCase):
 
     def testNoSOA(self):
         def bad():
-            z = dns.zone.from_text(no_soa_text, 'example.',
-                                   relativize=True)
+            dns.zone.from_text(no_soa_text, 'example.', relativize=True)
         self.failUnlessRaises(dns.zone.NoSOA, bad)
 
     def testNoNS(self):
         def bad():
-            z = dns.zone.from_text(no_ns_text, 'example.',
-                                   relativize=True)
+            dns.zone.from_text(no_ns_text, 'example.', relativize=True)
         self.failUnlessRaises(dns.zone.NoNS, bad)
 
     def testInclude(self):
@@ -409,8 +460,7 @@ class ZoneTestCase(unittest.TestCase):
 
     def testBadDirective(self):
         def bad():
-            z = dns.zone.from_text(bad_directive_text, 'example.',
-                                   relativize=True)
+            dns.zone.from_text(bad_directive_text, 'example.', relativize=True)
         self.failUnlessRaises(dns.exception.SyntaxError, bad)
 
     def testFirstRRStartsWithWhitespace(self):
@@ -427,14 +477,14 @@ class ZoneTestCase(unittest.TestCase):
         self.failUnless(z.origin == dns.name.from_text('example.'))
         def bad1():
             o = dns.name.from_text('example', None)
-            z = dns.zone.Zone(o)
+            dns.zone.Zone(o)
         self.failUnlessRaises(ValueError, bad1)
         def bad2():
-            z = dns.zone.Zone(1.0)
+            dns.zone.Zone(1.0)
         self.failUnlessRaises(ValueError, bad2)
 
     def testZoneOriginNone(self):
-        z = dns.zone.Zone(None)
+        dns.zone.Zone(None)
 
 if __name__ == '__main__':
     unittest.main()
